@@ -58,7 +58,9 @@ class DebugToolbarMiddleware(object):
         else:
             remote_addr = request.META.get('REMOTE_ADDR', None)
         if not remote_addr in settings.INTERNAL_IPS \
-                or request.is_ajax() or not settings.DEBUG:
+            or (request.is_ajax() and \
+                not debug_toolbar.urls._PREFIX in request.path) \
+                    or not settings.DEBUG:
             return False
         return True
 
@@ -88,10 +90,12 @@ class DebugToolbarMiddleware(object):
             if isinstance(response, HttpResponseRedirect):
                 redirect_to = response.get('Location', None)
                 if redirect_to:
+                    cookies = response.cookies
                     response = render_to_response(
                         'debug_toolbar/redirect.html',
                         {'redirect_to': redirect_to}
                     )
+                    response.cookies = cookies
         if response.status_code == 200:
             for panel in self.debug_toolbars[request].panels:
                 panel.process_response(request, response)
